@@ -101,6 +101,6 @@ class optimized_diff_match_patch:
                 stdout=subprocess.PIPE,
             )
             stdout = process.communicate()[0]
-            diffs = json.loads(stdout, encoding="utf-8")
+            diffs = json.loads(stdout)
             diffs = self._unescape_lr(diffs)
             return diffs
